@@ -46,7 +46,7 @@ public:
     QList<QUrl> selectedFiles() override;
 
 protected:
-    KFileWidget *m_fileWidget;
+    KFileWidget *const m_fileWidget;
 };
 
 class KDEPlatformFileDialogHelper : public QPlatformFileDialogHelper
@@ -81,7 +81,7 @@ private Q_SLOTS:
 
 private:
     void restoreSize();
-    KDEPlatformFileDialogBase *m_dialog;
+    KDEPlatformFileDialogBase *m_dialog = nullptr;
     bool m_directorySet = false;
     bool m_fileSelected = false;
     bool m_dialogInitialized = false;
